package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppDeposit;
import com.ruoyi.model.service.IAppDepositService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 保证金记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@RestController
@RequestMapping("/model/AppDeposit")
public class AppDepositController extends BaseController
{
    @Autowired
    private IAppDepositService appDepositService;

    /**
     * 查询保证金记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppDeposit:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppDeposit appDeposit)
    {
        startPage();
        List<AppDeposit> list = appDepositService.selectAppDepositList(appDeposit);
        return getDataTable(list);
    }

    /**
     * 导出保证金记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppDeposit:export')")
    @Log(title = "保证金记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppDeposit appDeposit) throws IOException {
        List<AppDeposit> list = appDepositService.selectAppDepositList(appDeposit);
        ExcelUtil<AppDeposit> util = new ExcelUtil<AppDeposit>(AppDeposit.class);
        util.exportExcel(response, list, "保证金记录数据");
    }

    /**
     * 获取保证金记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppDeposit:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appDepositService.selectAppDepositById(id));
    }

    /**
     * 新增保证金记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppDeposit:add')")
    @Log(title = "保证金记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppDeposit appDeposit)
    {
        return toAjax(appDepositService.insertAppDeposit(appDeposit));
    }

    /**
     * 修改保证金记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppDeposit:edit')")
    @Log(title = "保证金记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppDeposit appDeposit)
    {
        return toAjax(appDepositService.updateAppDeposit(appDeposit));
    }

    /**
     * 删除保证金记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppDeposit:remove')")
    @Log(title = "保证金记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appDepositService.deleteAppDepositByIds(ids));
    }
}
