package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppInvite;
import com.ruoyi.model.service.IAppInviteService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 邀请海报配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/AppInvite")
public class AppInviteController extends BaseController
{
    @Autowired
    private IAppInviteService appInviteService;

    /**
     * 查询邀请海报配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppInvite:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppInvite appInvite)
    {
        startPage();
        List<AppInvite> list = appInviteService.selectAppInviteList(appInvite);
        return getDataTable(list);
    }

    /**
     * 导出邀请海报配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppInvite:export')")
    @Log(title = "邀请海报配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppInvite appInvite) throws IOException {
        List<AppInvite> list = appInviteService.selectAppInviteList(appInvite);
        ExcelUtil<AppInvite> util = new ExcelUtil<AppInvite>(AppInvite.class);
        util.exportExcel(response, list, "邀请海报配置数据");
    }

    /**
     * 获取邀请海报配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppInvite:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appInviteService.selectAppInviteById(id));
    }

    /**
     * 新增邀请海报配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppInvite:add')")
    @Log(title = "邀请海报配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppInvite appInvite)
    {
        return toAjax(appInviteService.insertAppInvite(appInvite));
    }

    /**
     * 修改邀请海报配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppInvite:edit')")
    @Log(title = "邀请海报配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppInvite appInvite)
    {
        return toAjax(appInviteService.updateAppInvite(appInvite));
    }

    /**
     * 删除邀请海报配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppInvite:remove')")
    @Log(title = "邀请海报配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appInviteService.deleteAppInviteByIds(ids));
    }
}
