package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppPartnerdata;
import com.ruoyi.model.service.IAppPartnerdataService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 合伙人数据Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/AppPartnerdata")
public class AppPartnerdataController extends BaseController
{
    @Autowired
    private IAppPartnerdataService appPartnerdataService;

    /**
     * 查询合伙人数据列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerdata:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppPartnerdata appPartnerdata)
    {
        startPage();
        List<AppPartnerdata> list = appPartnerdataService.selectAppPartnerdataList(appPartnerdata);
        return getDataTable(list);
    }

    /**
     * 导出合伙人数据列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerdata:export')")
    @Log(title = "合伙人数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppPartnerdata appPartnerdata) throws IOException {
        List<AppPartnerdata> list = appPartnerdataService.selectAppPartnerdataList(appPartnerdata);
        ExcelUtil<AppPartnerdata> util = new ExcelUtil<AppPartnerdata>(AppPartnerdata.class);
        util.exportExcel(response, list, "合伙人数据数据");
    }

    /**
     * 获取合伙人数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerdata:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appPartnerdataService.selectAppPartnerdataById(id));
    }

    /**
     * 新增合伙人数据
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerdata:add')")
    @Log(title = "合伙人数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppPartnerdata appPartnerdata)
    {
        return toAjax(appPartnerdataService.insertAppPartnerdata(appPartnerdata));
    }

    /**
     * 修改合伙人数据
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerdata:edit')")
    @Log(title = "合伙人数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppPartnerdata appPartnerdata)
    {
        return toAjax(appPartnerdataService.updateAppPartnerdata(appPartnerdata));
    }

    /**
     * 删除合伙人数据
     */
    @PreAuthorize("@ss.hasPermi('model:AppPartnerdata:remove')")
    @Log(title = "合伙人数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appPartnerdataService.deleteAppPartnerdataByIds(ids));
    }
}
