package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppTransactionDetails;
import com.ruoyi.model.service.IAppTransactionDetailsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 交易明细记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@RestController
@RequestMapping("/model/AppTransactionDetails")
public class AppTransactionDetailsController extends BaseController
{
    @Autowired
    private IAppTransactionDetailsService appTransactionDetailsService;

    /**
     * 查询交易明细记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppTransactionDetails:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppTransactionDetails appTransactionDetails)
    {
        startPage();
        List<AppTransactionDetails> list = appTransactionDetailsService.selectAppTransactionDetailsList(appTransactionDetails);
        return getDataTable(list);
    }

    /**
     * 导出交易明细记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppTransactionDetails:export')")
    @Log(title = "交易明细记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppTransactionDetails appTransactionDetails) throws IOException {
        List<AppTransactionDetails> list = appTransactionDetailsService.selectAppTransactionDetailsList(appTransactionDetails);
        ExcelUtil<AppTransactionDetails> util = new ExcelUtil<AppTransactionDetails>(AppTransactionDetails.class);
        util.exportExcel(response, list, "交易明细记录数据");
    }

    /**
     * 获取交易明细记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppTransactionDetails:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appTransactionDetailsService.selectAppTransactionDetailsById(id));
    }

    /**
     * 新增交易明细记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppTransactionDetails:add')")
    @Log(title = "交易明细记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppTransactionDetails appTransactionDetails)
    {
        return toAjax(appTransactionDetailsService.insertAppTransactionDetails(appTransactionDetails));
    }

    /**
     * 修改交易明细记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppTransactionDetails:edit')")
    @Log(title = "交易明细记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppTransactionDetails appTransactionDetails)
    {
        return toAjax(appTransactionDetailsService.updateAppTransactionDetails(appTransactionDetails));
    }

    /**
     * 删除交易明细记录
     */
    @PreAuthorize("@ss.hasPermi('model:AppTransactionDetails:remove')")
    @Log(title = "交易明细记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appTransactionDetailsService.deleteAppTransactionDetailsByIds(ids));
    }
}
