package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppWithdrawalConfig;
import com.ruoyi.model.service.IAppWithdrawalConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 钱包提现配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@RestController
@RequestMapping("/model/AppWithdrawalConfig")
public class AppWithdrawalConfigController extends BaseController
{
    @Autowired
    private IAppWithdrawalConfigService appWithdrawalConfigService;

    /**
     * 查询钱包提现配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppWithdrawalConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppWithdrawalConfig appWithdrawalConfig)
    {
        startPage();
        List<AppWithdrawalConfig> list = appWithdrawalConfigService.selectAppWithdrawalConfigList(appWithdrawalConfig);
        return getDataTable(list);
    }

    /**
     * 导出钱包提现配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppWithdrawalConfig:export')")
    @Log(title = "钱包提现配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppWithdrawalConfig appWithdrawalConfig) throws IOException {
        List<AppWithdrawalConfig> list = appWithdrawalConfigService.selectAppWithdrawalConfigList(appWithdrawalConfig);
        ExcelUtil<AppWithdrawalConfig> util = new ExcelUtil<AppWithdrawalConfig>(AppWithdrawalConfig.class);
        util.exportExcel(response, list, "钱包提现配置数据");
    }

    /**
     * 获取钱包提现配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppWithdrawalConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appWithdrawalConfigService.selectAppWithdrawalConfigById(id));
    }

    /**
     * 新增钱包提现配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppWithdrawalConfig:add')")
    @Log(title = "钱包提现配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppWithdrawalConfig appWithdrawalConfig)
    {
        return toAjax(appWithdrawalConfigService.insertAppWithdrawalConfig(appWithdrawalConfig));
    }

    /**
     * 修改钱包提现配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppWithdrawalConfig:edit')")
    @Log(title = "钱包提现配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppWithdrawalConfig appWithdrawalConfig)
    {
        return toAjax(appWithdrawalConfigService.updateAppWithdrawalConfig(appWithdrawalConfig));
    }

    /**
     * 删除钱包提现配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppWithdrawalConfig:remove')")
    @Log(title = "钱包提现配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appWithdrawalConfigService.deleteAppWithdrawalConfigByIds(ids));
    }
}
