package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.ExamineConfig;
import com.ruoyi.model.service.IExamineConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 考核认证配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/config")
public class ExamineConfigController extends BaseController
{
    @Autowired
    private IExamineConfigService examineConfigService;

    /**
     * 查询考核认证配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:config:list')")
    @GetMapping("/list")
    public TableDataInfo list(ExamineConfig examineConfig)
    {
        startPage();
        List<ExamineConfig> list = examineConfigService.selectExamineConfigList(examineConfig);
        return getDataTable(list);
    }

    /**
     * 导出考核认证配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:config:export')")
    @Log(title = "考核认证配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ExamineConfig examineConfig) throws IOException {
        List<ExamineConfig> list = examineConfigService.selectExamineConfigList(examineConfig);
        ExcelUtil<ExamineConfig> util = new ExcelUtil<ExamineConfig>(ExamineConfig.class);
        util.exportExcel(response, list, "考核认证配置数据");
    }

    /**
     * 获取考核认证配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:config:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(examineConfigService.selectExamineConfigById(id));
    }

    /**
     * 新增考核认证配置
     */
    @PreAuthorize("@ss.hasPermi('model:config:add')")
    @Log(title = "考核认证配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ExamineConfig examineConfig)
    {
        return toAjax(examineConfigService.insertExamineConfig(examineConfig));
    }

    /**
     * 修改考核认证配置
     */
    @PreAuthorize("@ss.hasPermi('model:config:edit')")
    @Log(title = "考核认证配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ExamineConfig examineConfig)
    {
        return toAjax(examineConfigService.updateExamineConfig(examineConfig));
    }

    /**
     * 删除考核认证配置
     */
    @PreAuthorize("@ss.hasPermi('model:config:remove')")
    @Log(title = "考核认证配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(examineConfigService.deleteExamineConfigByIds(ids));
    }
}
