package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.ShortAnswerQuestions;
import com.ruoyi.model.service.IShortAnswerQuestionsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 简答题考试记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/ShortAnswerQuestions")
public class ShortAnswerQuestionsController extends BaseController
{
    @Autowired
    private IShortAnswerQuestionsService shortAnswerQuestionsService;

    /**
     * 查询简答题考试记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:ShortAnswerQuestions:list')")
    @GetMapping("/list")
    public TableDataInfo list(ShortAnswerQuestions shortAnswerQuestions)
    {
        startPage();
        List<ShortAnswerQuestions> list = shortAnswerQuestionsService.selectShortAnswerQuestionsList(shortAnswerQuestions);
        return getDataTable(list);
    }

    /**
     * 导出简答题考试记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:ShortAnswerQuestions:export')")
    @Log(title = "简答题考试记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ShortAnswerQuestions shortAnswerQuestions) throws IOException {
        List<ShortAnswerQuestions> list = shortAnswerQuestionsService.selectShortAnswerQuestionsList(shortAnswerQuestions);
        ExcelUtil<ShortAnswerQuestions> util = new ExcelUtil<ShortAnswerQuestions>(ShortAnswerQuestions.class);
        util.exportExcel(response, list, "简答题考试记录数据");
    }

    /**
     * 获取简答题考试记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:ShortAnswerQuestions:query')")
    @GetMapping(value = "/{shortAnswerQuestionsId}")
    public AjaxResult getInfo(@PathVariable("shortAnswerQuestionsId") Long shortAnswerQuestionsId)
    {
        return success(shortAnswerQuestionsService.selectShortAnswerQuestionsByShortAnswerQuestionsId(shortAnswerQuestionsId));
    }

    /**
     * 新增简答题考试记录
     */
    @PreAuthorize("@ss.hasPermi('model:ShortAnswerQuestions:add')")
    @Log(title = "简答题考试记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ShortAnswerQuestions shortAnswerQuestions)
    {
        return toAjax(shortAnswerQuestionsService.insertShortAnswerQuestions(shortAnswerQuestions));
    }

    /**
     * 修改简答题考试记录
     */
    @PreAuthorize("@ss.hasPermi('model:ShortAnswerQuestions:edit')")
    @Log(title = "简答题考试记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ShortAnswerQuestions shortAnswerQuestions)
    {
        return toAjax(shortAnswerQuestionsService.updateShortAnswerQuestions(shortAnswerQuestions));
    }

    /**
     * 删除简答题考试记录
     */
    @PreAuthorize("@ss.hasPermi('model:ShortAnswerQuestions:remove')")
    @Log(title = "简答题考试记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{shortAnswerQuestionsIds}")
    public AjaxResult remove(@PathVariable Long[] shortAnswerQuestionsIds)
    {
        return toAjax(shortAnswerQuestionsService.deleteShortAnswerQuestionsByShortAnswerQuestionsIds(shortAnswerQuestionsIds));
    }
}
