package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.TransactionDetails;
import com.ruoyi.model.service.ITransactionDetailsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 交易明细记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/TransactionDetails")
public class TransactionDetailsController extends BaseController
{
    @Autowired
    private ITransactionDetailsService transactionDetailsService;

    /**
     * 查询交易明细记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:TransactionDetails:list')")
    @GetMapping("/list")
    public TableDataInfo list(TransactionDetails transactionDetails)
    {
        startPage();
        List<TransactionDetails> list = transactionDetailsService.selectTransactionDetailsList(transactionDetails);
        return getDataTable(list);
    }

    /**
     * 导出交易明细记录列表
     */
    @PreAuthorize("@ss.hasPermi('model:TransactionDetails:export')")
    @Log(title = "交易明细记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TransactionDetails transactionDetails) throws IOException {
        List<TransactionDetails> list = transactionDetailsService.selectTransactionDetailsList(transactionDetails);
        ExcelUtil<TransactionDetails> util = new ExcelUtil<TransactionDetails>(TransactionDetails.class);
        util.exportExcel(response, list, "交易明细记录数据");
    }

    /**
     * 获取交易明细记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:TransactionDetails:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(transactionDetailsService.selectTransactionDetailsById(id));
    }

    /**
     * 新增交易明细记录
     */
    @PreAuthorize("@ss.hasPermi('model:TransactionDetails:add')")
    @Log(title = "交易明细记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TransactionDetails transactionDetails)
    {
        return toAjax(transactionDetailsService.insertTransactionDetails(transactionDetails));
    }

    /**
     * 修改交易明细记录
     */
    @PreAuthorize("@ss.hasPermi('model:TransactionDetails:edit')")
    @Log(title = "交易明细记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TransactionDetails transactionDetails)
    {
        return toAjax(transactionDetailsService.updateTransactionDetails(transactionDetails));
    }

    /**
     * 删除交易明细记录
     */
    @PreAuthorize("@ss.hasPermi('model:TransactionDetails:remove')")
    @Log(title = "交易明细记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(transactionDetailsService.deleteTransactionDetailsByIds(ids));
    }
}
