package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.UserBindingConfig;
import com.ruoyi.model.service.IUserBindingConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 合伙人绑定页面配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-05
 */
@RestController
@RequestMapping("/model/UserBindingConfig")
public class UserBindingConfigController extends BaseController
{
    @Autowired
    private IUserBindingConfigService userBindingConfigService;

    /**
     * 查询合伙人绑定页面配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:UserBindingConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(UserBindingConfig userBindingConfig)
    {
        startPage();
        List<UserBindingConfig> list = userBindingConfigService.selectUserBindingConfigList(userBindingConfig);
        return getDataTable(list);
    }

    /**
     * 导出合伙人绑定页面配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:UserBindingConfig:export')")
    @Log(title = "合伙人绑定页面配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserBindingConfig userBindingConfig) throws IOException {
        List<UserBindingConfig> list = userBindingConfigService.selectUserBindingConfigList(userBindingConfig);
        ExcelUtil<UserBindingConfig> util = new ExcelUtil<UserBindingConfig>(UserBindingConfig.class);
        util.exportExcel(response, list, "合伙人绑定页面配置数据");
    }

    /**
     * 获取合伙人绑定页面配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:UserBindingConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(userBindingConfigService.selectUserBindingConfigById(id));
    }

    /**
     * 新增合伙人绑定页面配置
     */
    @PreAuthorize("@ss.hasPermi('model:UserBindingConfig:add')")
    @Log(title = "合伙人绑定页面配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UserBindingConfig userBindingConfig)
    {
        return toAjax(userBindingConfigService.insertUserBindingConfig(userBindingConfig));
    }

    /**
     * 修改合伙人绑定页面配置
     */
    @PreAuthorize("@ss.hasPermi('model:UserBindingConfig:edit')")
    @Log(title = "合伙人绑定页面配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UserBindingConfig userBindingConfig)
    {
        return toAjax(userBindingConfigService.updateUserBindingConfig(userBindingConfig));
    }

    /**
     * 删除合伙人绑定页面配置
     */
    @PreAuthorize("@ss.hasPermi('model:UserBindingConfig:remove')")
    @Log(title = "合伙人绑定页面配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(userBindingConfigService.deleteUserBindingConfigByIds(ids));
    }
}
