package com.ruoyi.model.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.model.mapper.AppDepositMapper;
import com.ruoyi.model.domain.AppDeposit;
import com.ruoyi.model.service.IAppDepositService;

/**
 * 保证金记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@Service
public class AppDepositServiceImpl implements IAppDepositService 
{
    @Autowired
    private AppDepositMapper appDepositMapper;

    /**
     * 查询保证金记录
     * 
     * @param id 保证金记录主键
     * @return 保证金记录
     */
    @Override
    public AppDeposit selectAppDepositById(Long id)
    {
        return appDepositMapper.selectAppDepositById(id);
    }

    /**
     * 查询保证金记录列表
     * 
     * @param appDeposit 保证金记录
     * @return 保证金记录
     */
    @Override
    public List<AppDeposit> selectAppDepositList(AppDeposit appDeposit)
    {
        return appDepositMapper.selectAppDepositList(appDeposit);
    }

    /**
     * 新增保证金记录
     * 
     * @param appDeposit 保证金记录
     * @return 结果
     */
    @Override
    public int insertAppDeposit(AppDeposit appDeposit)
    {
        appDeposit.setCreateTime(DateUtils.getNowDate());
        return appDepositMapper.insertAppDeposit(appDeposit);
    }

    /**
     * 修改保证金记录
     * 
     * @param appDeposit 保证金记录
     * @return 结果
     */
    @Override
    public int updateAppDeposit(AppDeposit appDeposit)
    {
        appDeposit.setUpdateTime(DateUtils.getNowDate());
        return appDepositMapper.updateAppDeposit(appDeposit);
    }

    /**
     * 批量删除保证金记录
     * 
     * @param ids 需要删除的保证金记录主键
     * @return 结果
     */
    @Override
    public int deleteAppDepositByIds(Long[] ids)
    {
        return appDepositMapper.deleteAppDepositByIds(ids);
    }

    /**
     * 删除保证金记录信息
     * 
     * @param id 保证金记录主键
     * @return 结果
     */
    @Override
    public int deleteAppDepositById(Long id)
    {
        return appDepositMapper.deleteAppDepositById(id);
    }

    /**
     * 查询保证金记录列表
     *
     * @param appDeposit 保证金记录
     * @return 保证金记录
     */
    @Override
    public List<AppDeposit> getAppDepositListByUserId(Long userId)
    {
        return appDepositMapper.getAppDepositListByUserId(userId);
    }
}
